@@ -1,5 +1,40 @@
 library(stringr, warn.conflicts = FALSE)
-library(purrr, warn.conflicts = FALSE)
+
+# list() as a functor (cf. purrr::lift())
+lift <- function(f) {
+  function(args) do.call(f, args)
+}
+
+# Error monad (cf. purrr::safely())
+safely <- function(f) {
+  function(...) {
+    tryCatch(
+      list(result = f(...), error = NULL),
+      error = function(e) list(result = NULL, error = e)
+    )
+  }
+}
+
+# Cf. purrr::map_lgl()
+map_lgl <- local({
+  as_function <- function(f) {
+    if (is.function(f))
+      return(f)
+    # Otherwise, assume f is a one-sided formula
+    new_fn(alist(. = ), f[[2]], environment(f))
+  }
+
+  function(xs, f, ...) {
+    f <- as_function(f)
+    vapply(xs, f, ..., FUN.VALUE = logical(1))
+  }
+})
+
+new_fn <- function(args, body = quote(NULL), env = parent.frame()) {
+  f <- eval(call("function", as.pairlist(args), body))
+  environment(f) <- env
+  f
+}
 
 noneval_checks <- list(
   x ~ is.numeric,
@@ -53,13 +88,6 @@ args_list <- list(
   alist(x = 0, y = 1, z = x + y, ... = )
 )
 
-make_fnc <- function(args, body = quote(NULL), env = parent.frame()) {
-  args <- as.pairlist(args)
-  f <- eval(call("function", args, body))
-  environment(f) <- env
-  f
-}
-
 # Make a function that simply passes the inputs as a list
 #
 # If the output of firmly() of such a dummy function matches the output of the
@@ -71,13 +99,13 @@ pass_args <- function(args) {
     call[[1L]] <- as.name("list")
     eval(call)
   })
-  make_fnc(args, body)
+  new_fn(args, body)
 }
 
 # Expect exactly n errors matching pattern
 expect_n_errors <- function(n, f, args, pattern) {
-  suppressWarnings(do.call(purrr::safely(f), args, quote = TRUE)) %>% {
-    stringr::str_count(.$error, pattern)
+  suppressWarnings(do.call(safely(f), args, quote = TRUE)) %>% {
+    stringr::str_count(as.character(.$error), pattern)
   } %>%
     expect_equal(n)
 }
